@@ -26,9 +26,12 @@ class GtkSourceView4(Tarball, Meson):
         Project.__init__(
             self,
             "gtksourceview4",
-            archive_url="https://download.gnome.org/sources/gtksourceview/4.8/gtksourceview-4.8.4.tar.xz",
+            version="4.8.4",
+            lastversion_major=4,
+            repository="https://gitlab.gnome.org/GNOME/gtksourceview",
+            archive_url="https://download.gnome.org/sources/gtksourceview/{major}.{minor}/gtksourceview-{version}.tar.xz",
             hash="7ec9d18fb283d1f84a3a3eff3b7a72b09a10c9c006597b3fbabbb5958420a87d",
-            dependencies=["meson", "ninja", "gtk3", "pkg-config"],
+            dependencies=["meson", "ninja", "gtk3", "pkgconf", "libxml2"],
         )
         if Project.opts.enable_gi:
             self.add_dependency("gobject-introspection")
@@ -47,9 +50,12 @@ class GtkSourceView5(Tarball, Meson):
         Project.__init__(
             self,
             "gtksourceview5",
-            archive_url="https://download.gnome.org/sources/gtksourceview/5.6/gtksourceview-5.6.1.tar.xz",
+            version="5.6.1",
+            lastversion_major=5,
+            repository="https://gitlab.gnome.org/GNOME/gtksourceview",
+            archive_url="https://download.gnome.org/sources/gtksourceview/{major}.{minor}/gtksourceview-{version}.tar.xz",
             hash="659d9cc9d034a114f07e7e134ee80d77dec0497cb1516ae5369119c2fcb9da16",
-            dependencies=["meson", "ninja", "gtk4", "pkg-config"],
+            dependencies=["meson", "ninja", "gtk4", "pkgconf", "libxml2"],
         )
         if Project.opts.enable_gi:
             self.add_dependency("gobject-introspection")
