@@ -26,7 +26,9 @@ class HelloWorld(NullExpander, Meson):
         Project.__init__(
             self,
             "hello-world",
+            version="1.0.0",
             dependencies=["meson"],
+            internal=True,
         )
 
     def build(self):
