@@ -26,7 +26,9 @@ class Libxml2(Tarball, Meson):
         Project.__init__(
             self,
             "libxml2",
-            archive_url="https://download.gnome.org/sources/libxml2/2.10/libxml2-2.10.3.tar.xz",
+            version="2.10.3",
+            repository="https://gitlab.gnome.org/GNOME/libxml2",
+            archive_url="https://download.gnome.org/sources/libxml2/{major}.{minor}/libxml2-{version}.tar.xz",
             hash="5d2cc3d78bec3dbe212a9d7fa629ada25a7da928af432c93060ff5c17ee28a9c",
             dependencies=["win-iconv", "meson", "ninja"],
         )
