@@ -319,8 +319,8 @@ class Builder:
 
         completed_process = subprocess.run(
             [f"{vswhere}", "-all", "-products", "*", "-format", "json", "-utf8"],
-            text=True,
             capture_output=True,
+            encoding="utf-8",
         )
         try:
             completed_process.check_returncode()
@@ -375,11 +375,8 @@ class Builder:
                 % (vcvars_bat, vs_path, opts.platform)
             )
         return subprocess.check_output(
-            'cmd.exe /c ""%s"%s>NUL && set"'
-            % (
-                vcvars_bat,
-                add_opts,
-            ),
+            f'cmd.exe /c ""{vcvars_bat}"{add_opts}>NUL && set"',
+            encoding="utf-8",
             shell=True,
             text=True,
         )
