@@ -29,8 +29,7 @@ def convert_to_msys(path):
     path = path
     if path[1] != ":":
         raise NotADirectoryError("Path doesn't contain a drive letter like C:")
-    path = f"/{path[0]}" + path[2:].replace("\\", "/")
-    return path
+    return f"/{path[0]}" + path[2:].replace("\\", "/")
 
 
 def _rmtree_error_handler(func, path, exc_info):
@@ -57,13 +56,13 @@ def rmtree_full(dest_dir, retry=False):
 
 
 def read_file(file_name):
-    with open(file_name) as fi:
+    with open(file_name, encoding="utf-8") as fi:
         rt = [line.rstrip("\n") for line in fi]
     return rt
 
 
 def write_file(file_name, content):
-    with open(file_name, "wt") as fo:
+    with open(file_name, "wt", encoding="utf-8") as fo:
         for i in content:
             fo.write(f"{i}\n")
 
